FORMAL_MARKERS = [
    "please", "kindly", "therefore", "however",
    "furthermore", "regarding", "respectfully",
    "do not", "does not", "cannot"
]

INFORMAL_MARKERS = [
    "hey", "hi", "yeah", "ok", "okay",
    "gonna", "wanna", "dont", "can't",
    "cool", "lol"
]


def formal_rule(text: str) -> int:
    """
    Returns:
        1 -> Formal
        0 -> Informal
    """
    t = text.lower()

    for m in INFORMAL_MARKERS:
        if m in t:
            return 0

    for m in FORMAL_MARKERS:
        if m in t:
            return 1

    # no strong signal
    return 0
